# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'print (($ExtUtils::MakeMaker::VERSION < 6.30) ? 1 : 0);' 2>/dev/null || echo 0)

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Eval-Closure
Version:	0.11
Release:	1.%{__distinit}%{__distvers}
Summary:	Safely and cleanly create closures via string eval
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Eval-Closure/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DO/DOY/Eval-Closure-%{version}.tar.gz
Patch0:		Eval-Closure-0.10-old-eumm.patch
Patch1:		Eval-Closure-0.11-old-Test::More.patch
Patch2:		Eval-Closure-0.11-no-Test::Requires.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -un)
BuildArch:	noarch
BuildRequires:	perl(B)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Devel::LexAlias) >= 0.05
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(PadWalker)
BuildRequires:	perl(Perl::Tidy)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Sub::Exporter)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Output)
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Pod) >= 1.41
# Test::Requires needs Test::Builder::Module, only available with perl >= 5.8.8 (FC-5 onwards)
%if %(perl -e 'print $] >= 5.008008 ? 1 : 0;')
BuildRequires:	perl(Test::Requires)
%endif
BuildRequires:	perl(Try::Tiny)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Devel::LexAlias) >= 0.05
Requires:	perl(Perl::Tidy)

%description
String eval is often used for dynamic code generation. For instance, Moose uses
it heavily, to generate inlined versions of accessors and constructors, which
speeds code up at runtime by a significant amount.  String eval is not without
its issues however - it's difficult to control the scope it's used in (which
determines which variables are in scope inside the eval), and it can be quite
slow, especially if doing a large number of evals.

This module attempts to solve both of those problems. It provides an
eval_closure function, which evals a string in a clean environment, other than
a fixed list of specified variables. It also caches the result of the eval, so
that doing repeated evals of the same source, even with a different
environment, will be much faster (but note that the description is part of the
string to be evaled, so it must also be the same (or non-existent) if caching
is to work properly).

%prep
%setup -q -n Eval-Closure-%{version}

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%if %{old_eumm}
%patch0
%endif

# We need to patch the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch1
%endif

# If we don't have Test::Requires, we need to patch it out of the test suite
%if %(perl -e 'print $] >= 5.008008 ? 0 : 1;')
%patch2
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes LICENSE README
%{perl_vendorlib}/Eval/
%{_mandir}/man3/Eval::Closure.3pm*

%changelog
* Wed Jul 31 2013 Paul Howarth <paul@city-fan.org> 0.11-1
- update to 0.11:
  - add "alias => 1" option for making closure variables actually alias the
    closed over variables (so the variable referenced in the environment
    hashref will actually be updated by changes made in the closure)
- BR:/R: perl(Devel::LexAlias) ≥ 0.05
- update patches

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> 0.10-2
- Perl 5.18 rebuild

* Thu Jul 11 2013 Paul Howarth <paul@city-fan.org> 0.10-1
- update to 0.10:
  - support lexical subs on 5.18+
  - fix pod links
- explicitly run the extra tests
- update patches

* Sun Jul  8 2012 Paul Howarth <paul@city-fan.org> 0.08-2
- BR: perl(Carp) and perl(File::Temp)
- don't need to remove empty directories from the buildroot

* Fri Feb 10 2012 Paul Howarth <paul@city-fan.org> 0.08-1
- update to 0.08:
  - remove a double layer of string eval that was introduced in 0.07 as an
    intermediate step in figuring out the unique package thing - it's not
    necessary with the final implementation, and just makes things slower and
    hides errors

* Sat Feb  4 2012 Paul Howarth <paul@city-fan.org> 0.07-1
- update to 0.07:
  - the given source is now evaled in a unique package for every eval_closure
    call (it always used to be evaled in the Eval::Closure package, which was
    especially buggy); this is to avoid issues where one eval_closure modifies
    the global environment (by, say, importing a function), which could mess
    up a later call
  - unfortunately, this means that the memoization stuff no longer works, since
    it will result in memoized results using the original package, which
    defeats the purpose; I'm open to suggestions on how to safely reenable it
  - clean up a few stray lexicals we were still closing over in the eval
- update patches

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> 0.06-2
- rebuild for perl 5.14.1 in Rawhide
- fix dist tag for CentOS 6 and Scientific Linux

* Mon Jun  6 2011 Paul Howarth <paul@city-fan.org> 0.06-1
- update to 0.06:
  - the dumped source from setting $ENV{EVAL_CLOSURE_PRINT_SOURCE} didn't show
    the captured variable creation properly
- update patch for old ExtUtils::MakeMaker versions

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> 0.05-1
- update to 0.05:
  - make sure Perl::Tidy doesn't look at @ARGV

* Mon Apr 18 2011 Paul Howarth <paul@city-fan.org> 0.04-1
- update to 0.04:
  - stop using Memoize, which apparently doesn't work properly under mod_perl
    in some situations

* Tue Apr 12 2011 Paul Howarth <paul@city-fan.org> 0.03-2
- import from Fedora

* Thu Mar  3 2011 Iain Arnell <iarnell@gmail.com> 0.03-1
- update to latest upstream version

* Tue Feb  8 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 0.02-2
- rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jan 28 2011 Iain Arnell <iarnell@gmail.com> 0.02-1
- update to latest upstream version

* Sun Jan 23 2011 Iain Arnell <iarnell@gmail.com> 0.01-1
- specfile autogenerated by cpanspec 1.78
